[![Python package](https://github.com/ceesvandegriend/swrf/actions/workflows/main.yml/badge.svg)](https://github.com/ceesvandegriend/swrf/actions/workflows/main.yml)

# swrf / Sorrowful

Check that the home network is connected to the
internet by the main connection ans not by the fall-back.

Try to connect to the public, well known website and publish
the result on a MessageQueue topic.

Multiple subscribers are able to receive this messages.
